==> krita-4.2.8.2.tar.xz: krita-4.2.8.2/plugins/color/lcms2engine/IccColorSpaceEngine.h <==
/*
 *  Copyright (c) 2008 Cyrille Berger <cberger@cberger.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef _KO_ICC_COLOR_SPACE_ENGINE_H_
#define _KO_ICC_COLOR_SPACE_ENGINE_H_

#include <KoColorSpaceEngine.h>

class IccColorSpaceEngine : public KoColorSpaceEngine
{
public:
    IccColorSpaceEngine();
    ~IccColorSpaceEngine() override;
    const KoColorProfile *addProfile(const QString &filename) override;
    const KoColorProfile *addProfile(const QByteArray &data) override;
    void removeProfile(const QString &filename) override;
    KoColorConversionTransformation *createColorTransformation(const KoColorSpace *srcColorSpace,
            const KoColorSpace *dstColorSpace,
            KoColorConversionTransformation::Intent renderingIntent,
            KoColorConversionTransformation::ConversionFlags conversionFlags) const override;
    KoColorProofingConversionTransformation *createColorProofingTransformation(const KoColorSpace *srcColorSpace,
            const KoColorSpace *dstColorSpace,
            const KoColorSpace *proofingSpace,
            KoColorConversionTransformation::Intent renderingIntent, KoColorConversionTransformation::Intent proofingIntent,
            KoColorConversionTransformation::ConversionFlags conversionFlags, quint8 *gamutWarning, double adaptationState) const override;
    quint32 computeColorSpaceType(const KoColorSpace *cs) const;

    bool supportsColorSpace(const QString& colorModelId, const QString& colorDepthId, const KoColorProfile *profile) const override;
private:
    struct Private;
    Private *const d;
};

#endif

==> krita-5.1.4.tar.xz: krita-5.1.4/plugins/color/lcms2engine/IccColorSpaceEngine.h <==
/*
 *  SPDX-FileCopyrightText: 2008 Cyrille Berger <cberger@cberger.net>
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#ifndef _KO_ICC_COLOR_SPACE_ENGINE_H_
#define _KO_ICC_COLOR_SPACE_ENGINE_H_

#include <KoColorSpaceEngine.h>

class IccColorSpaceEngine : public KoColorSpaceEngine
{
public:
    IccColorSpaceEngine();
    ~IccColorSpaceEngine() override;
    const KoColorProfile *addProfile(const QString &filename) override;
    const KoColorProfile *addProfile(const QByteArray &data) override;
    const KoColorProfile * getProfile(const QVector<double> &colorants, ColorPrimaries colorPrimaries, TransferCharacteristics transferFunction) override;
    void removeProfile(const QString &filename) override;
    KoColorConversionTransformation *createColorTransformation(const KoColorSpace *srcColorSpace,
            const KoColorSpace *dstColorSpace,
            KoColorConversionTransformation::Intent renderingIntent,
            KoColorConversionTransformation::ConversionFlags conversionFlags) const override;
    KoColorProofingConversionTransformation *createColorProofingTransformation(const KoColorSpace *srcColorSpace,
            const KoColorSpace *dstColorSpace,
            const KoColorSpace *proofingSpace,
            KoColorConversionTransformation::Intent renderingIntent, KoColorConversionTransformation::Intent proofingIntent,
            KoColorConversionTransformation::ConversionFlags conversionFlags, quint8 *gamutWarning, double adaptationState) const override;
    quint32 computeColorSpaceType(const KoColorSpace *cs) const;

    bool supportsColorSpace(const QString& colorModelId, const QString& colorDepthId, const KoColorProfile *profile) const override;
private:
    struct Private;
    Private *const d;
};

#endif
